@@ -91,9 +91,11 @@ class TransferPortal:
 
     def __init__(self):
         self.session = requests.Session()
-        self.collegedf = pd.read_csv('https://raw.githubusercontent.com/Natron0919/twofourseven/main/Data/colleges.csv')
+        self.fbcollegedf = pd.read_csv('https://raw.githubusercontent.com/Natron0919/twofourseven/main/Data/fbcolleges.csv')
+        self.bbcollegedf = pd.read_csv('https://raw.githubusercontent.com/Natron0919/twofourseven/main/Data/bbcolleges.csv')
 
-    def getData(self, year):
+
+    def getFootballData(self, year):
         
         self.year = year
         # Get html from site for appropriate year. 
@@ -122,7 +124,9 @@ class TransferPortal:
                 team1.append('NULL')
 
         team1 = [''.join(x) for x in team1] # Turn all entries into strings instead of one length lists
+        team1 = [x.lower() for x in team1]
         team2 = [''.join(x) for x in team2] # Turn all entries into strings instead of one length lists
+        team2 = [x.lower() for x in team2]
 
         # Create dictionary from all lists
         di = {'Player' : players, 'POS' : positions, 'Rating' : scores, 'Team_Old' : team1, 'Team_New' : team2}
@@ -137,9 +141,63 @@ class TransferPortal:
         df['Team_Old'] = df['Team_Old'].replace(r'^\s*$', 'NULL', regex = True)
         df['Team_New'] = df['Team_New'].replace(r'^\s*$', 'NULL', regex = True)
 
-        df = pd.merge(df, self.collegedf, left_on = ['Team_Old'], right_on = ['Team'], how = 'left')
+        df = pd.merge(df, self.fbcollegedf, left_on = ['Team_Old'], right_on = ['Team'], how = 'left')
         df = df.drop(columns = {'Team'})
-        df = pd.merge(df, self.collegedf, left_on = ['Team_New'], right_on = ['Team'], how = 'left', suffixes = ['_Old', '_New'])
+        df = pd.merge(df, self.fbcollegedf, left_on = ['Team_New'], right_on = ['Team'], how = 'left', suffixes = ['_Old', '_New'])
+        df = df.drop(columns = {'Team'})
+        df = df.replace(np.nan, 'NULL')
+
+        return df
+
+    def getBasketballData(self, year):
+        
+        self.year = year
+        # Get html from site for appropriate year. 
+        res = requests.get('https://247sports.com/Season/' + str(year) + '-Basketball/TransferPortal/', headers={'User-Agent': 'Mozilla/5.0'})
+        res.raise_for_status()
+        site = html.fromstring(res.content)
+
+        # Return lists of player names, position, and rating from HS
+        players = site.xpath("//div[@class='player']/a/text()")
+        positions = site.xpath("//div[@class='position']/text()")
+        scores = site.xpath("//span[child::span[text()='(HS)']]/text()")
+
+        # Return initial team and new team for each player
+        player_list = site.xpath("//li[@class='portal-list_itm']")
+        team1 = [] # Empty list for original team
+        team2 = [] # Empty list for new team
+        for x in player_list: # For-loop to get all players original team
+            try:
+                team2.append(x.xpath("div[contains(@class, 'transfer-institution')]/a[2]/img/@alt"))
+            except:
+                team2.append('NULL')
+        for x in player_list: # For-loop to get all players new team
+            try:
+                team1.append(x.xpath("div[contains(@class, 'transfer-institution')]/a[1]/img/@alt"))
+            except:
+                team1.append('NULL')
+
+        team1 = [''.join(x) for x in team1] # Turn all entries into strings instead of one length lists
+        team1 = [x.lower() for x in team1]
+        team2 = [''.join(x) for x in team2] # Turn all entries into strings instead of one length lists
+        team2 = [x.lower() for x in team2]
+
+        # Create dictionary from all lists
+        di = {'Player' : players, 'POS' : positions, 'Rating' : scores, 'Team_Old' : team1, 'Team_New' : team2}
+
+        # Turn dictionary into DataFrame
+        df = pd.DataFrame(di)
+        df['Player'] = df['Player'].astype(str)
+        df['POS'] = df['POS'].astype(str)
+        df['Rating'] = df['Rating'].str.strip()
+        df = df.replace('N/A', 'NULL')
+        df.insert(0, 'Year', year)
+        df['Team_Old'] = df['Team_Old'].replace(r'^\s*$', 'NULL', regex = True)
+        df['Team_New'] = df['Team_New'].replace(r'^\s*$', 'NULL', regex = True)
+
+        df = pd.merge(df, self.bbcollegedf, left_on = ['Team_Old'], right_on = ['Team'], how = 'left')
+        df = df.drop(columns = {'Team'})
+        df = pd.merge(df, self.bbcollegedf, left_on = ['Team_New'], right_on = ['Team'], how = 'left', suffixes = ['_Old', '_New'])
         df = df.drop(columns = {'Team'})
         df = df.replace(np.nan, 'NULL')
 
